@@ -10,26 +10,23 @@
 
 
 /* .C calls */
-extern void mcmc_missing(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                         void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                         void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                         void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                         void *, void *, void *);
 
-
-extern void ordinal_missing_ppmx(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                                 void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                                 void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                                 void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                                 void *, void *, void *, void *, void *,void *, void *, void *, void *);
+extern void GAUSSIAN_PPMX(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                          void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                          void *, void *, void *, void *, void *,void *);
 
 extern void ORDINAL_PPMX(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
                          void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
                          void *, void *, void *, void *, void *,void *, void *, void *);
 
-extern void GAUSSIAN_PPMX(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                          void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
-                          void *, void *, void *, void *, void *,void *);
+extern void GAUSSIAN_PPMX_MISSING(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                                  void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                                  void *, void *, void *, void *, void *,void *, void *, void *, void *, void *);
+
+extern void ORDINAL_PPMX_MISSING(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                                 void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                                 void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
+                                 void *, void *);
 
 extern void mcmc_sppm(void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
                       void *, void *, void *, void *, void *,void *, void *, void *, void *, void *,
@@ -41,10 +38,10 @@ extern void rppmx(void *, void *, void *, void *, void *,void *, void *, void *,
 
 
 static const R_CMethodDef CEntries[] = {
-    {"mcmc_missing", (DL_FUNC) &mcmc_missing, 43},
-    {"ordinal_missing_ppmx", (DL_FUNC) &ordinal_missing_ppmx, 49},
+    {"gaussian_ppmx", (DL_FUNC) &GAUSSIAN_PPMX, 26},
     {"ordinal_ppmx", (DL_FUNC) &ORDINAL_PPMX, 28},
-    {"GAUSSIAN_PPMX", (DL_FUNC) &GAUSSIAN_PPMX, 26},
+    {"gaussian_ppmx_missing", (DL_FUNC) &GAUSSIAN_PPMX_MISSING, 30},
+    {"ordinal_ppmx_missing", (DL_FUNC) &ORDINAL_PPMX_MISSING, 32},
     {"mcmc_sppm", (DL_FUNC) &mcmc_sppm, 27},
     {"rppmx", (DL_FUNC) &rppmx, 20},
     {NULL, NULL, 0}
